@@ -1,4 +1,5 @@
 import asyncio
+import threading
 import time
 from ..Scheduler import IntervalTask
 from ..dbserver.base import Base, ENGINE_DICT, mysql
@@ -23,6 +24,7 @@ class data_manager(object):
         if 'charset' not in self.t_data:
             self.t_data['charset'] = 'utf8mb4'
 
+        self.threading_pool = {}
         self.sql_pool = {}
         print('creating DB connection pool...')
         # for i in range(0,self.min_keep_connection):
@@ -31,6 +33,7 @@ class data_manager(object):
         IntervalTask(data_manager.keep_cycle, self.keep_connect)
         self.mem_cache = {}
 
+
     def get_table_name(self,table_name):
         if '.' in table_name:
             return table_name
@@ -39,22 +42,34 @@ class data_manager(object):
 
     def keep_connect(self):
         # print('查看死亡链接')
-        can_delete_sql = []
-        # can_update_sql = []
+        # can_delete_sql = []
+        # count = 0
+        # for sql in self.sql_pool.values():
+        #     if int(time.time()) - sql.last_execute_time > 40:
+        #         count += 1
+        #         can_delete_sql.append(id(sql))
+        #
+        # self.kill_unused_connection(can_delete_sql)
+        # for sql in self.sql_pool.values():
+        #     if sql.is_busy() == False:
+        #         sql.become_busy()
+        #         sql.keep_connect()
+        #         sql.become_free()
+        # return
+        # <===================>
+        can_delete_sql_id_list = []
         count = 0
         for sql in self.sql_pool.values():
             if int(time.time()) - sql.last_execute_time > 40:
                 count += 1
-                can_delete_sql.append(id(sql))
-
-        self.kill_unused_connection(can_delete_sql)
+                can_delete_sql_id_list.append(id(sql))
+        self.kill_unused_connection(can_delete_sql_id_list)
         for sql in self.sql_pool.values():
             if sql.is_busy() == False:
                 sql.become_busy()
                 sql.keep_connect()
                 sql.become_free()
 
-        return
 
     def kill_unused_connection(self, kill_connect):
         count = 0
@@ -77,21 +92,38 @@ class data_manager(object):
             return None
 
     def find_free_sql(self):
-        try:
-            sql_list = self.sql_pool.values()
-            for sql in sql_list:
-                if sql.is_busy() is False and int(time.time()) - sql.last_execute_time < 29:
-                    sql.become_busy()
-                    return sql
-        except Exception as e:
-            print(str(e),'查找空闲sql链接时遍历错误')
-            # pass
-        print('数据库连接池全忙状态，创建新的数据库链接')
+        # try:
+        #     sql_list = self.sql_pool.values()
+        #     for sql in sql_list:
+        #         if sql.is_busy() is False and int(time.time()) - sql.last_execute_time < 29:
+        #             sql.become_busy()
+        #             return sql
+        # except Exception as e:
+        #     print(str(e),'查找空闲sql链接时遍历错误')
+        #     # pass
+        # print('数据库连接池全忙状态，创建新的数据库链接')
+        #
+        # sql = self.create_new_sql()
+        # sql.become_busy()
+        # self.add_new_sql(sql)
+        # print('创建完毕新连接id:', id(sql))
+        # print('数据库连接池全忙状态，创建新的数据库链接', '新连接id:', id(sql))
+        # return sql
+
+        thread_id = threading.currentThread().ident
+        # print('本次数据库请求线程id', thread_id)
+
+        if thread_id in self.threading_pool:
+            sql_id = self.threading_pool[thread_id]
+            if sql_id in self.sql_pool:
+                sql = self.sql_pool[sql_id]
+                sql.become_busy()
+                return sql
+
         sql = self.create_new_sql()
         sql.become_busy()
         self.add_new_sql(sql)
-        # print('创建完毕新连接id:', id(sql))
-        # print('数据库连接池全忙状态，创建新的数据库链接', '新连接id:', id(sql))
+        self.threading_pool[thread_id] = id(sql)
         return sql
 
     def add_new_sql(self, sql):
