@@ -182,8 +182,8 @@ class Data(object):
 
     @staticmethod
     def make_select_query(table, conditions, or_cond=None, fields=None, group=None, order=None, limit=None):
-        return Base.find_info(table, conditions, or_cond, fields, group, order, limit)
-
+        sql_frame,params = Base.find_info(table, conditions, or_cond, fields, group, order, limit)
+        return sql_frame%params
 
 
 
